==> apache-servicecomb-java-chassis-distribution-2.8.29-src.zip: apache-servicecomb-java-chassis-distribution-2.8.29-src/handlers/handler-router/src/main/java/org/apache/servicecomb/router/custom/ServiceCombRouterDistributor.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.servicecomb.router.custom;

import java.util.HashMap;
import java.util.Map;

import org.apache.servicecomb.loadbalance.ServiceCombServer;
import org.apache.servicecomb.router.distribute.AbstractRouterDistributor;
import org.springframework.stereotype.Component;

@Component
public class ServiceCombRouterDistributor extends
    AbstractRouterDistributor<ServiceCombServer> {

  public ServiceCombRouterDistributor() {
    init(
        instance -> MicroserviceCache.getInstance()
            .getService(instance.getInstance().getServiceId()).getVersion(),
        instance -> MicroserviceCache.getInstance()
            .getService(instance.getInstance().getServiceId()).getServiceName(),
        instance -> {
          Map<String, String> properties = new HashMap<>();
          properties.putAll(MicroserviceCache.getInstance()
              .getService(instance.getInstance().getServiceId()).getProperties());
          properties.putAll(instance.getInstance().getProperties());
          return properties;
        });
  }
}

==> apache-servicecomb-java-chassis-distribution-3.3.0-src.zip: apache-servicecomb-java-chassis-distribution-3.3.0-src/handlers/handler-router/src/main/java/org/apache/servicecomb/router/custom/ServiceCombRouterDistributor.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.servicecomb.router.custom;

import java.util.HashMap;
import java.util.Map;

import org.apache.servicecomb.loadbalance.ServiceCombServer;
import org.apache.servicecomb.router.distribute.AbstractRouterDistributor;

public class ServiceCombRouterDistributor extends
    AbstractRouterDistributor<ServiceCombServer> {

  public ServiceCombRouterDistributor() {
    init(
        instance -> instance.getInstance().getVersion(),
        instance -> instance.getInstance().getServiceName(),
        instance -> {
          Map<String, String> properties = new HashMap<>();
          properties.putAll(instance.getInstance().getProperties());
          return properties;
        });
  }
}
